@@ -20,6 +20,7 @@
 #include <skalibs/cbuffer.h>
 #include <skalibs/cdb.h>
 #include <skalibs/cdbmake.h>
+#include <skalibs/devino.h>
 #include <skalibs/direntry.h>
 #include <skalibs/diuint32.h>
 #include <skalibs/diuint.h>
@@ -29,6 +30,7 @@
 #include <skalibs/envalloc.h>
 #include <skalibs/env.h>
 #include <skalibs/exec.h>
+#include <skalibs/cspawn.h>
 #include <skalibs/fmtscan.h>
 #include <skalibs/functypes.h>
 #include <skalibs/gccattributes.h>
@@ -46,8 +48,6 @@
 #include <skalibs/skamisc.h>
 #include <skalibs/socket.h>
 #include <skalibs/stralloc.h>
-#include <skalibs/strerr.h>
-#include <skalibs/strerr2.h>
 #include <skalibs/tai.h>
 
 #endif
