@@ -7,9 +7,10 @@
 
 int envalloc_merge (genalloc *v, char const *const *envp, size_t envlen, char const *modifs, size_t modiflen)
 {
-  size_t n = envlen + 1 + byte_count(modifs, modiflen, '\0') ;
+  size_t modifn = byte_count(modifs, modiflen, '\0') ;
+  size_t n = envlen + 1 + modifn ;
   if (!genalloc_readyplus(char const *, v, n)) return 0 ;
-  n = env_mergen(genalloc_s(char const *, v) + genalloc_len(char const *, v), n, envp, envlen, modifs, modiflen, n) ;
+  n = env_mergen(genalloc_s(char const *, v) + genalloc_len(char const *, v), n, envp, envlen, modifs, modiflen, modifn) ;
   genalloc_setlen(char const *, v, genalloc_len(char const *, v) + n) ;
   return 1 ;
 }
