@@ -12,10 +12,9 @@ void sha1_feed (SHA1Schedule *ctx, unsigned char inb)
   ctx->in[ctx->b>>2] |= T8(inb) ;
   if (++ctx->b >= 64)
   {
-    unsigned int i = 0 ;
     sha1_transform(ctx->buf, ctx->in) ;
     ctx->b = 0 ;
-    for (i = 0 ; i < 16 ; i++) ctx->in[i] = 0 ;
+    for (uint32_t i = 0 ; i < 16 ; i++) ctx->in[i] = 0 ;
   }
   tmp = ctx->bits[0] ;
   ctx->bits[0] += 8 ;
