@@ -1,6 +1,7 @@
 /* ISC license. */
 
 #include <stdint.h>
+
 #include <skalibs/bytestr.h>
 #include <skalibs/sha256.h>
 #include "sha256-internal.h"
@@ -12,10 +13,9 @@ void sha256_feed (SHA256Schedule *ctx, unsigned char inb)
   ctx->in[ctx->b>>2] |= T8(inb) ;
   if (++ctx->b >= 64)
   {
-    unsigned int i = 0 ;
     sha256_transform(ctx->buf, ctx->in) ;
     ctx->b = 0 ;
-    for (; i < 16 ; i++) ctx->in[i] = 0 ;
+    for (uint32_t i = 0; i < 16 ; i++) ctx->in[i] = 0 ;
   }
   tmp = ctx->bits[0] ;
   ctx->bits[0] += 8 ;
