@@ -6,7 +6,7 @@
 
 int bufalloc_flush (bufalloc *ba)
 {
-  ba->p += allreadwrite((iofunc_t_ref)ba->op, ba->fd, ba->x.s + ba->p, ba->x.len - ba->p) ;
+  ba->p += allreadwrite((io_func_ref)ba->op, ba->fd, ba->x.s + ba->p, ba->x.len - ba->p) ;
   bufalloc_clean(ba) ;
   return !ba->x.len ;
 }
