@@ -2,7 +2,7 @@
 
 #include <skalibs/cbuffer.h>
 
-size_t cbuffer_unget (cbuffer_t *b, size_t len)
+size_t cbuffer_unget (cbuffer *b, size_t len)
 {
   size_t max = cbuffer_available(b) ;
   if (len > max) len = max ;
