@@ -3,4 +3,4 @@
 #include <skalibs/buffer.h>
 #include <skalibs/genwrite.h>
 
-genwrite_t genwrite_stderr = GENWRITE_BUFFER_INIT(buffer_2) ;
+genwrite genwrite_stderr = GENWRITE_BUFFER_INIT(buffer_2) ;
