@@ -3,4 +3,4 @@
 #include <skalibs/buffer.h>
 #include <skalibs/genwrite.h>
 
-genwrite_t genwrite_stdout = GENWRITE_BUFFER_INIT(buffer_1) ;
+genwrite genwrite_stdout = GENWRITE_BUFFER_INIT(buffer_1) ;
