@@ -4,7 +4,7 @@
 #include <skalibs/uint64.h>
 #include <skalibs/djbtime.h>
 
-int localtm_from_tai (struct tm *l, tai_t const *t, int tz)
+int localtm_from_tai (struct tm *l, tai const *t, int tz)
 {
   uint64_t u ;
   int h = ltm64_from_tai(&u, t) ;
