@@ -1,9 +1,10 @@
 /* ISC license. */
 
 #include <time.h>
+
 #include <skalibs/djbtime.h>
 
-int localtmn_from_sysclock (localtmn_t *l, tain_t const *a, int tz)
+int localtmn_from_sysclock (localtmn *l, tain const *a, int tz)
 {
   struct tm t ;
   if (!localtm_from_sysclock(&t, a->sec.x, tz)) return 0 ;
