@@ -3,7 +3,7 @@
 #include <time.h>
 #include <skalibs/djbtime.h>
 
-int localtmn_from_tain (localtmn_t *l, tain_t const *a, int tz)
+int localtmn_from_tain (localtmn *l, tain const *a, int tz)
 {
   struct tm t ;
   if (!localtm_from_tai(&t, tain_secp(a), tz)) return 0 ;
