@@ -1,7 +1,7 @@
 /* ISC license. */
 
-#include <string.h>
 #include <limits.h>
+#include <string.h>
 #include <stdlib.h>
 #include <skalibs/stralloc.h>
 #include <skalibs/djbunix.h>
@@ -10,9 +10,20 @@ int sarealpath (stralloc *sa, char const *path)
 {
   if (sa->s)
   {
+#ifdef PATH_MAX
     if (!stralloc_readyplus(sa, PATH_MAX)) return -1 ;
     if (!realpath(path, sa->s + sa->len)) return -1 ;
     sa->len += strlen(sa->s + sa->len) ;
+#else
+    char *p = realpath(path, 0) ;
+    if (!p) return -1 ;
+    if (!stralloc_cats(sa, p) || !stralloc_0(sa))
+    {
+      free(p) ;
+      return -1 ;
+    }
+    free(p) ;
+#endif
   }
   else
   {
