@@ -2,13 +2,13 @@
 
 #include <sys/uio.h>
 #include <string.h>
+
 #include <skalibs/siovec.h>
 
 size_t siovec_gather (struct iovec const *v, unsigned int n, char *s, size_t max)
 {
   size_t w = 0 ;
-  unsigned int i = 0 ;
-  for (; i < n && w < max ; i++)
+  for (unsigned int i = 0 ; i < n && w < max ; i++)
   {
     size_t len = v[i].iov_len ;
     if (len > max - w) len = max - w ;
