@@ -3,7 +3,7 @@
 #include <skalibs/uint32.h>
 #include <skalibs/socket.h>
 
-int socket_deadlineconnstamp4_u32 (int s, uint32_t ip, uint16_t port, tain_t const *deadline, tain_t *stamp)
+int socket_deadlineconnstamp4_u32 (int s, uint32_t ip, uint16_t port, tain const *deadline, tain *stamp)
 {
   char pack[4] ;
   uint32_pack_big(pack, ip) ;
