@@ -7,7 +7,7 @@ int stralloc_shrink (stralloc *sa)
 {
   if (sa->a > sa->len)
   {
-    if (!alloc_re((void **)&sa->s, sa->a, sa->len)) return 0 ;
+    if (!alloc_re(&sa->s, sa->a, sa->len)) return 0 ;
     sa->a = sa->len ;
   }
   return 1 ;
