@@ -2,7 +2,7 @@
 
 #include <skalibs/tai.h>
 
-int tain_add (tain_t *t, tain_t const *u, tain_t const *v)
+int tain_add (tain *t, tain const *u, tain const *v)
 {
   t->sec.x = u->sec.x + v->sec.x ;
   t->nano = u->nano + v->nano ;
