@@ -3,7 +3,7 @@
 #include <skalibs/fmtscan.h>
 #include <skalibs/tai.h>
 
-size_t tain_fmt (char *s, tain_t const *a)
+size_t tain_fmt (char *s, tain const *a)
 {
   char pack[TAIN_PACK] ;
   tain_pack(pack, a) ;
