@@ -4,7 +4,7 @@
 
 #include <skalibs/tai.h>
 
-int tain_now_set_wallclock (tain_t *now)
+int tain_now_set_wallclock (tain *now)
 {
   tain_now = &tain_wallclock_read ;
   return tain_wallclock_read(now) ;
