@@ -2,4 +2,4 @@
 
 #include <skalibs/tai.h>
 
-tain_t const tain_zero = TAIN_ZERO ;
+tain const tain_zero = TAIN_ZERO ;
