@@ -3,7 +3,7 @@
 #include <time.h>
 #include <skalibs/tai.h>
 
-int timespec_sysclock_from_tain (struct timespec *ts, tain_t const *t)
+int timespec_sysclock_from_tain (struct timespec *ts, tain const *t)
 {
   if (!time_sysclock_from_tai(&ts->tv_sec, &t->sec)) return 0 ;
   ts->tv_nsec = t->nano ;
