@@ -10,9 +10,9 @@
 
 #include <skalibs/nonposix.h>
 
-#include <fcntl.h>
 #include <unistd.h>
 
+#include <skalibs/fcntl.h>
 #include <skalibs/unix-transactional.h>
 
 int access_at (int dirfd, char const *file, int amode, unsigned int flag)
