@@ -10,7 +10,7 @@ static ssize_t get (buffer *b)
   return sanitize_read(buffer_fill(b)) ;
 }
 
-ssize_t buffer_timed_fill (buffer *b, tain_t const *deadline, tain_t *stamp)
+ssize_t buffer_timed_fill (buffer *b, tain const *deadline, tain *stamp)
 {
-  return timed_get(b, (initfunc_t_ref)&buffer_getfd, (getfunc_t_ref)&get, deadline, stamp) ;
+  return timed_get(b, (init_func_ref)&buffer_getfd, (get_func_ref)&get, deadline, stamp) ;
 }
