@@ -11,7 +11,7 @@ int opengetlnclose (char const *fn, stralloc *sa, int sep)
   char buf[BUFFER_INSIZE] ;
   buffer b ;
   int r ;
-  int fd = open_readb(fn) ;
+  int fd = openc_readb(fn) ;
   if (fd < 0) return -1 ;
   buffer_init(&b, &fd_readv, fd, buf, BUFFER_INSIZE) ;
   r = skagetln(&b, sa, sep) ;
