@@ -11,7 +11,7 @@
 #include "skaclient-internal.h"
 
 int skaclient_start_async (
-  skaclient_t *a,
+  skaclient *a,
   char *bufss,
   size_t bufsn,
   char *auxbufss,
@@ -20,7 +20,7 @@ int skaclient_start_async (
   size_t bufan,
   char *auxbufas,
   size_t auxbufan,
-  kolbak_closure_t *q,
+  kolbak_closure *q,
   size_t qlen,
   char const *path,
   uint32_t options,
@@ -28,7 +28,7 @@ int skaclient_start_async (
   size_t beforelen,
   char const *after,
   size_t afterlen,
-  skaclient_cbdata_t *blah)
+  skaclient_cbdata *blah)
 {
   int fd = ipc_stream_nbcoe() ;
   if (fd < 0) return 0 ;
@@ -40,7 +40,7 @@ int skaclient_start_async (
   }
   a->pid = 0 ;
   a->options = options & ~SKACLIENT_OPTION_WAITPID ;
-  if (!kolbak_enqueue(&a->kq, (unixmessage_handler_func_t_ref)&skaclient_start_cb, blah))
+  if (!kolbak_enqueue(&a->kq, (unixmessage_handler_func_ref)&skaclient_start_cb, blah))
   {
     skaclient_end(a) ;
     return 0 ;
