@@ -3,7 +3,7 @@
 #include <skalibs/bufalloc.h>
 #include <skalibs/textmessage.h>
 
-int textmessage_sender_getfd (textmessage_sender_t const *ts)
+int textmessage_sender_getfd (textmessage_sender const *ts)
 {
   return bufalloc_fd(&ts->out) ;
 }
