@@ -4,4 +4,4 @@
 
 #include <skalibs/textmessage.h>
 
-textmessage_sender_t textmessage_sender_x_ = TEXTMESSAGE_SENDER_ZERO ;
+textmessage_sender textmessage_sender_x_ = TEXTMESSAGE_SENDER_ZERO ;
