@@ -25,8 +25,8 @@ static ssize_t get (struct blah_s *blah)
   return sanitize_read(skagetln(blah->b, blah->sa, blah->sep)) ;
 }
 
-int timed_getln (buffer *b, stralloc *sa, char sep, tain_t const *deadline, tain_t *stamp)
+int timed_getln (buffer *b, stralloc *sa, char sep, tain const *deadline, tain *stamp)
 {
   struct blah_s blah = { .b = b, .sa = sa, .sep = sep } ;
-  return timed_get(&blah, (initfunc_t_ref)&getfd, (getfunc_t_ref)&get, deadline, stamp) ;
+  return timed_get(&blah, (init_func_ref)&getfd, (get_func_ref)&get, deadline, stamp) ;
 }
